@@ -6,13 +6,21 @@ from pydantic import AnyUrl, BeforeValidator, HttpUrl, computed_field, model_val
 from pydantic_settings import BaseSettings, SettingsConfigDict
 from typing_extensions import Self
 
-from mtmai.core.coreutils import is_in_huggingface, is_in_vercel
+from mtmai.core.coreutils import is_in_vercel
 from mtmai.mtlibs import mtutils
+from mtmlib.env import is_in_huggingface
 
 from .__version__ import version
 
+# Get the directory the script is running from
+APP_ROOT = os.getenv("MTMAI_APP_ROOT", os.getcwd())
+
+HEADER_SITE_HOST = "X-Site-Host" # 通过http header 传递前端域名
+
 
 def parse_cors(v: Any) -> list[str] | str:
+    if v == "*":
+        return v
     if isinstance(v, str) and not v.startswith("["):
         return [i.strip() for i in v.split(",")]
     elif isinstance(v, list | str):
@@ -24,7 +32,12 @@ class Settings(BaseSettings):
     model_config = SettingsConfigDict(
         env_file=".env", env_ignore_empty=True, extra="ignore"
     )
-    app_name: str = "Mtmai API"
+    # 是否是生产环境
+    is_production: bool = (
+        os.environ.get("MTM_DEV", "development").lower() == "production"
+    )
+    app_name: str = "Mtmai"
+    work_dir: str = os.getcwd()
     PORT: int | None = 8000
     HOSTNAME: str | None = "0.0.0.0"  # noqa: S104
     SERVE_IP: str | None = "0.0.0.0"  # noqa: S104
@@ -51,9 +64,9 @@ class Settings(BaseSettings):
             return f"http://{self.DOMAIN}"
         return f"https://{self.DOMAIN}"
 
-    BACKEND_CORS_ORIGINS: Annotated[
-        list[AnyUrl] | str, BeforeValidator(parse_cors)
-    ] = []
+    BACKEND_CORS_ORIGINS: Annotated[list[AnyUrl] | str, BeforeValidator(parse_cors)] = (
+        "*"
+    )
 
     # db
     DATABASE_URL: str | None = None  # config("DATABASE_URL", cast=Secret)
@@ -61,6 +74,7 @@ class Settings(BaseSettings):
 
     API_V1_STR: str = "/api/v1"
     VERSION: str | None = version
+    OPENAPI_JSON_PATH: str = "mtmai/mtmai/openapi.json"
 
     vercel_token: str | None = None
 
@@ -222,5 +236,34 @@ class Settings(BaseSettings):
 
     NPM_TOKEN: str | None = None
 
+    # langgraph
+    langgraph_checkpointer: Literal["memory", "postgres"] = "postgres"
+
+    GROQ_TOKEN: str | None = ""
+    TOGETHER_TOKEN: str | None = ""
+
+    # http
+    HTTP_PROXY: str | None = None
+    HTTPS_PROXY: str | None = None
+    # socks
+    SOCKS_PROXY: str | None = None
+
+    # https://serper.dev/api-key
+    SERPER_DEV_TOKEN: str | None = None
+
+    # selenium
+    SELENIUM_VERSION: str = "4.24.0"
+    SELENIUM_DISPLAY: str | None = None  # ":1"
+    SELENIUM_PORT: int = 4444
+    SELENIUM_HUB_URL: str | None = None  # "http://localhost:4444/wd/hub"
+
+    # mtmflow
+    MTMFLOW_URL_BASE: str = "http://localhost:8001"
+
+    # 其他
+    graph_config_path: str = "configs/graph_config.yml"
+    # chainlit
+    CHAINLIT_AUTH_SECRET: str | None = None
+
 
 settings = Settings()  # type: ignore
