@@ -1,21 +1,27 @@
-import asyncio
 import logging
+import re
 from pathlib import Path
 
-from mtmlib.mtutils import bash
-from mtmlib.version_tag import patch_git_tag_version, read_tag
-
 from mtmai.core import coreutils
 from mtmai.core.config import settings
 from mtmai.mtlibs import mtutils
 from mtmai.mtlibs.mtutils import command_exists, is_in_gitpod, npm_patch_version
 from mtmai.mtlibs.temboio import run_tmpbo_instance1
+from mtmlib.github import git_commit_push
+from mtmlib.mtutils import bash
+from mtmlib.version_tag import patch_git_tag_version, read_tag
 
 from . import huggingface
 
 logger = logging.getLogger()
 
 
+def get_bun_bin():
+    if not command_exists("bun"):
+        bash("curl -fsSL https://bun.sh/install | bash")
+    return str(Path.home() / ".bun" / "bin" / "bun")
+
+
 def init_project():
     if not coreutils.is_in_gitpod():
         return
@@ -23,7 +29,7 @@ def init_project():
     if not mtutils.command_exists("bun"):
         bash("curl -fsSL https://bun.sh/install | bash")
     if not Path("./node_modules").exists():
-        bash(". ~/.bashrc && bun i")
+        bash(f"{get_bun_bin()} i")
 
     if not Path(".env").exists():
         bash("cp env/dev.env .env")
@@ -38,12 +44,20 @@ def init_project():
         npmrc = Path.home().joinpath(".npmrc")
         npmrc.write_text(f"//registry.npmjs.org/:_authToken={settings.NPM_TOKEN}\n")
 
+    # if command_exists("cursor"):
+    #     bash("cursor --version")
+    #     bash("cursor --install-extension ms-python.vscode-pylance")
+    #     bash("cursor --install-extension ms-python.python")
+    #     bash("cursor --install-extension ms-toolsai.jupyter")
+    #     bash("cursor --install-extension ms-toolsai.vscode-jupyter-slideshow")
+
     huggingface.hf_trans1_clone()
 
 
 def init_github_settings():
     # 拉取所有标签, 如果仅拉起最浅层源码,会因缺少 tag 致构建失败
     bash("git fetch --tags")
+    bash("(git fetch --unshallow || true)")
     bash("git config --replace-all --global pull.rebase false")
     bash(
         "git config --replace-all --global user.name a && git config --replace-all --global user.email a@a.com"
@@ -64,8 +78,6 @@ ENV DATABASE_URL={settings.DATABASE_URL}
 ENV LOKI_USER={settings.LOKI_USER}
 ENV GRAFANA_TOKEN={settings.GRAFANA_TOKEN}
 ENV LOKI_ENDPOINT={settings.LOKI_ENDPOINT}
-
-
 RUN sudo apt update
 
 """)
@@ -83,16 +95,6 @@ app_port:  {settings.FRONT_PORT}
     return {"ok": True}
 
 
-# def release_pip_package():
-#     bash("poetry config repositories.pypi https://pypi.org/legacy/")
-#     bash(f"poetry config pypi-token.pypi {settings.POETRY_PYPI_TOKEN_PYPI}")
-
-#     try:
-#         bash("poetry publish")
-#     except Exception as e:
-#         logger.info("发布失败 %s", e)
-
-
 def run_clean():
     bun_cache_dir = Path.home().joinpath(".bun/install/cache")
     bash(f"rm -rdf {bun_cache_dir}")
@@ -124,36 +126,39 @@ def docker_build_base():
     logger.info("✅ build docker image_base")
 
 
-def run_deploy():
-    asyncio.run(run_tmpbo_instance1())
+async def run_deploy():
+    await dp_vercel_mtmaiadmin()
+    await run_tmpbo_instance1()
     logger.info("✅ tembo io pushed")
-
     hf_trans1_commit()
     logger.info("✅ hf_space_commit")
+    git_commit_push()
+    logger.info("✅ git_commit_push")
 
 
-py_projects = ["mtmai", "mtmdb", "mtmlib", "mtmtrain", "mtmai-client"]
+py_projects = [
+    "mtmai",
+    "mtmdb",
+    "mtmlib",
+    "mtmtrain",
+    "mtmai-client",
+    "mtmscreentocode",
+    "mtmflow",
+]
 
 
 def run_testing():
     for project in py_projects:
-        testing_dir = Path(f"{project}/{project}/tests")
-        if testing_dir.exists():
+        if Path(f"{project}/{project}/tests").exists():
             bash(f"cd {project} && coverage run -m pytest ")
             logger.info("✅ testing ok!")
 
 
 def release_py():
-    gen()
     version_tag = read_tag()
     logger.info("version tag: %s", version_tag)
-    run_testing()
+    # run_testing()
     for project in py_projects:
-        # testing_dir = Path(f"{project}/{project}/tests")
-        # if testing_dir.exists():
-        #     bash(f"cd {project} && coverage run -m pytest ")
-        #     logger.info("✅ testing ok!")
-
         dist_dir = Path(f"{project}/dist")
         if dist_dir.exists():
             bash(f"rm -rdf {dist_dir}")
@@ -174,19 +179,38 @@ def release_py():
 
 
 def release_npm():
-    npm_packages = ["apps/mtmaiweb", "packages/mtmeditor"]
+    npm_packages = [
+        "apps/mtmaiweb",
+        "apps/mtmaiadmin",
+        "packages/mtmeditor",
+        "packages/mtmscreentocode",
+        "packages/mtxuilib",
+        "packages/mtxlib",
+        "packages/mtmaiapi",
+    ]
 
-    bash("bun run turbo build")
+    bash(f"{get_bun_bin()} run turbo build")
 
     for package in npm_packages:
         npm_patch_version(package)
-    bash("bun run changeset publish --no-git-tag")
+    bash(f"{get_bun_bin()} run changeset publish --no-git-tag")
     logger.info("✅ release_npm ok!")
 
 
-def dp_cfpage():
+async def dp_cfpage():
+    logger.info("🚀 正在部署 cfpage")
     from mtmlib import vercel
 
+    pages = ["apps/mtmaiweb/src/app/(web)/layout.tsx"]
+    pre_content = Path(pages[0]).read_text()
+    # Check if the current runtime is nodejs before replacing
+    if re.search(r'runtime\s*=\s*["\']nodejs["\']', pre_content):
+        new_content = re.sub(r'runtime\s*=\s*"nodejs"', r'runtime="edge"', pre_content)
+        Path(pages[0]).write_text(new_content)
+        logger.info("✅ 替换layout 源码中的 runtime 为 edge")
+    else:
+        new_content = pre_content
+
     vercel.deploy_vercel(
         project_dir="apps/mtmaiweb",
         is_cfpage=True,
@@ -194,15 +218,22 @@ def dp_cfpage():
         vercel_token=settings.vercel_token,
     )
 
+    # 恢复
+    Path(pages[0]).write_text(pre_content)
+    logger.info("✅ 恢复layout 源码中的 runtime 为原来的值")
+    git_commit_push()
 
-def gen():
-    """生产相关客户端代码"""
-    # python 客户端库
-    if not mtutils.command_exists("openapi-python-client"):
-        bash(
-            "pip install openapi-python-client && openapi-python-client --install-completion"
-        )
-    bash("openapi-python-client generate --path mtmai/mtmai/openapi.json --overwrite")
 
-    # typescript 客户端库
-    bash("cd packages/mtmaiapi && bun run gen")
+async def dp_vercel_mtmaiadmin():
+    logger.info("🚀 正在部署到 vercel")
+    from mtmlib import vercel
+
+    vercel.deploy_vercel(
+        project_dir="apps/mtmaiadmin",
+        is_cfpage=False,
+        project_name="mtmaiadmin",
+        vercel_token=settings.vercel_token,
+        deploy_to_vercel=True,
+        build_local=False,
+    )
+    git_commit_push()
