@@ -5,10 +5,10 @@ from pathlib import Path
 
 import httpx
 from fastapi import APIRouter
-from mtmlib.mtutils import bash
 
 from mtmai.core.config import settings
 from mtmai.mtlibs import mtutils
+from mtmlib.mtutils import bash
 
 router = APIRouter()
 
@@ -19,7 +19,6 @@ logger = logging.getLogger()
 
 
 async def docker_build_mtmai():
-    # container_image_name = "docker.io/gitgit188/tmpboai"
     project_version = mtutils.get_pyproject_version("mtmai")
     logger.info("当前项目版本 %s", project_version)
 
@@ -34,7 +33,6 @@ async def docker_build_mtmai():
 
 async def run_tmpbo_instance1():
     project_version = mtutils.get_pyproject_version("mtmai")
-    # container_image_name = "docker.io/gitgit188/tmpboai"
     await asyncio.to_thread(
         bash,
         "cd mtmai && poetry export --format requirements.txt --output requirements.txt --without-hashes --without dev",
@@ -67,6 +65,10 @@ async def run_tmpbo_instance1():
                                     "name": "DATABASE_URL",
                                     "value": settings.DATABASE_URL,
                                 },
+                                {
+                                    "name": "LANGFLOW_DATABASE_URL",
+                                    "value": settings.DATABASE_URL,
+                                },
                                 {
                                     "name": "CF_TUNNEL_TOKEN",
                                     "value": settings.CF_TUNNEL_TOKEN_TEMBO,
@@ -79,10 +81,6 @@ async def run_tmpbo_instance1():
                                     "name": "MAIN_GH_USER",
                                     "value": settings.MAIN_GH_USER,
                                 },
-                                # {
-                                #     "name": "GITHUB_APP_ID",
-                                #     "value": settings.GITHUB_APP_ID,
-                                # },
                                 {
                                     "name": "GITHUB_CLIENT_ID",
                                     "value": settings.GITHUB_CLIENT_ID,
@@ -95,6 +93,26 @@ async def run_tmpbo_instance1():
                                     "name": "HUGGINGFACEHUB_API_TOKEN",
                                     "value": settings.HUGGINGFACEHUB_API_TOKEN,
                                 },
+                                {
+                                    "name": "SEARXNG_URL_BASE",
+                                    "value": settings.SEARXNG_URL_BASE,
+                                },
+                                {
+                                    "name": "GROQ_TOKEN",
+                                    "value": settings.GROQ_TOKEN,
+                                },
+                                {
+                                    "name": "TOGETHER_TOKEN",
+                                    "value": settings.TOGETHER_TOKEN,
+                                },
+                                {
+                                    "name": "CLOUDFLARE_AI_TOKEN",
+                                    "value": settings.CLOUDFLARE_AI_TOKEN,
+                                },
+                                {
+                                    "name": "CHAINLIT_AUTH_SECRET",
+                                    "value": settings.CHAINLIT_AUTH_SECRET,
+                                },
                             ],
                             "resources": {
                                 "requests": {"cpu": "500m", "memory": "2000Mi"},
@@ -123,7 +141,7 @@ async def run_tmpbo_instance1():
                                                 "spec": {
                                                     "accessModes": ["ReadWriteOnce"],
                                                     "resources": {
-                                                        "requests": {"storage": "2Gi"}
+                                                        "requests": {"storage": "10Gi"}
                                                     },
                                                 }
                                             }
@@ -136,7 +154,7 @@ async def run_tmpbo_instance1():
                                                 "spec": {
                                                     "accessModes": ["ReadWriteOnce"],
                                                     "resources": {
-                                                        "requests": {"storage": "2Gi"}
+                                                        "requests": {"storage": "10Gi"}
                                                     },
                                                 }
                                             }
