@@ -1,6 +1,6 @@
 from sqlmodel import Session
 
-from mtmai.curd import crud
+from mtmai.crud import crud
 from mtmai.models.models import Item, ItemCreate
 from mtmai.tests.utils.user import create_random_user
 from mtmai.tests.utils.utils import random_lower_string
